==> qmmp-0.12.14.tar.bz2: qmmp-0.12.14/src/plugins/Engines/mplayer/translations/mplayer_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>MplayerEngineFactory</name>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="34"/>
        <source>Mplayer Plugin</source>
        <translation>MPlayer įskiepis</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="37"/>
        <source>Video Files</source>
        <translation>Video bylos</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="84"/>
        <source>About MPlayer Plugin</source>
        <translation>Apie MPlayer Qmmp įskiepį</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="85"/>
        <source>Qmmp MPlayer Plugin</source>
        <translation>Qmmp MPlayer įskiepis</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="86"/>
        <source>This plugin uses MPlayer as backend</source>
        <translation>Šis įskiepis naudoja Mplayer video grojimui</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="87"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MplayerMetaDataModel</name>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="39"/>
        <source>Size</source>
        <translation>Dydis</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="39"/>
        <source>KiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="65"/>
        <source>Demuxer</source>
        <translation>Demuxeris</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="67"/>
        <source>Video format</source>
        <translation>Video formatas</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="68"/>
        <source>FPS</source>
        <translation>KPS</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="69"/>
        <source>Video codec</source>
        <translation>Video kodėkas</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="70"/>
        <source>Aspect ratio</source>
        <translation>Kraštinių santykis</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="71"/>
        <source>Video bitrate</source>
        <translation>Video kokybė</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="71"/>
        <location filename="../mplayermetadatamodel.cpp" line="76"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="74"/>
        <source>Audio codec</source>
        <translation>Audio kodėkas</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="75"/>
        <source>Sample rate</source>
        <translation>Dažnis</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="75"/>
        <source>Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="76"/>
        <source>Audio bitrate</source>
        <translation>Audio kokybė</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="77"/>
        <source>Channels</source>
        <translation>Kanalai</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="72"/>
        <source>Resolution</source>
        <translation>Rezoliucija</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="29"/>
        <location filename="../settingsdialog.cpp" line="37"/>
        <location filename="../settingsdialog.cpp" line="46"/>
        <location filename="../settingsdialog.cpp" line="47"/>
        <location filename="../settingsdialog.cpp" line="61"/>
        <location filename="../settingsdialog.cpp" line="62"/>
        <source>default</source>
        <translation>Numatytas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPlayer Settings</source>
        <translation>MPlayer nustatymai</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Audio:</source>
        <translation>Audio:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="72"/>
        <source>Synchronization factor:</source>
        <translation>Sinchronizacijos korekcija:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>Extra options:</source>
        <translation>Papildomi pasirinkimai:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>Extra command line options</source>
        <translation>Papildomi komandinės eilutės pasirinkimai</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Audio/video auto synchronization</source>
        <translation>Audio/Video automatinė sinchronizacija</translation>
    </message>
</context>
</TS>

==> qmmp_1.1.10.orig.tar.bz2: qmmp-1.1.10/src/plugins/Engines/mplayer/translations/mplayer_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>MplayerEngineFactory</name>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="34"/>
        <source>Mplayer Plugin</source>
        <translation>MPlayer įskiepis</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="37"/>
        <source>Video Files</source>
        <translation>Video bylos</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="83"/>
        <source>About MPlayer Plugin</source>
        <translation>Apie MPlayer Qmmp įskiepį</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="84"/>
        <source>Qmmp MPlayer Plugin</source>
        <translation>Qmmp MPlayer įskiepis</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="85"/>
        <source>This plugin uses MPlayer as backend</source>
        <translation>Šis įskiepis naudoja Mplayer video grojimui</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="86"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MplayerMetaDataModel</name>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="38"/>
        <source>Size</source>
        <translation>Dydis</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="38"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="75"/>
        <source>Length</source>
        <translation>Ilgis</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="77"/>
        <source>Demuxer</source>
        <translation>Demuxeris</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="80"/>
        <source>Video format</source>
        <translation>Video formatas</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="82"/>
        <source>FPS</source>
        <translation>KPS</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="84"/>
        <source>Video codec</source>
        <translation>Video kodėkas</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="86"/>
        <source>Aspect ratio</source>
        <translation>Kraštinių santykis</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="88"/>
        <source>Video bitrate</source>
        <translation>Video kokybė</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="95"/>
        <source>Audio codec</source>
        <translation>Audio kodėkas</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="97"/>
        <source>Sample rate</source>
        <translation>Dažnis</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="99"/>
        <source>Audio bitrate</source>
        <translation>Audio kokybė</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="101"/>
        <source>Channels</source>
        <translation>Kanalai</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="103"/>
        <source>Resolution</source>
        <translation>Rezoliucija</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="29"/>
        <location filename="../settingsdialog.cpp" line="37"/>
        <location filename="../settingsdialog.cpp" line="46"/>
        <location filename="../settingsdialog.cpp" line="47"/>
        <location filename="../settingsdialog.cpp" line="61"/>
        <location filename="../settingsdialog.cpp" line="62"/>
        <source>default</source>
        <translation>Numatytas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPlayer Settings</source>
        <translation>MPlayer nustatymai</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Audio:</source>
        <translation>Audio:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="72"/>
        <source>Synchronization factor:</source>
        <translation>Sinchronizacijos korekcija:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>Extra options:</source>
        <translation>Papildomi pasirinkimai:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>Extra command line options</source>
        <translation>Papildomi komandinės eilutės pasirinkimai</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Audio/video auto synchronization</source>
        <translation>Audio/Video automatinė sinchronizacija</translation>
    </message>
</context>
</TS>
